@@ -1601,7 +1601,8 @@ gint insert;
 	gint insert1, insert2;
 
 		insert1 = insert2 = 0;
-		if(flt->number)
+		//2068664 test for empty string as well
+		if( flt->number && (*flt->number != 0) )
 		{
 			if(txn->number)
 			{
@@ -1611,7 +1612,8 @@ gint insert;
 		else
 			insert1 = 1;
 
-		if(flt->memo)
+		//2068664 test for empty string as well
+		if( flt->memo && (*flt->memo != 0) )
 		{
 			//#1668036 always try match on txn memo first
 			if(txn->memo)
