@@ -172,7 +172,7 @@ gdouble tmpval = val1 - val2;
 gboolean hb_amount_equal(gdouble val1, gdouble val2)
 {
 gdouble tmpval1, tmpval2;
-	
+
 	tmpval1 = hb_amount_round(val1, 2);
 	tmpval2 = hb_amount_round(val2, 2);
 
@@ -180,6 +180,23 @@ gdouble tmpval1, tmpval2;
 }
 
 
+gint hb_amount_forced_sign(const gchar *txt)
+{
+gint retval = HB_AMT_SIGN_OFF;
+
+	if( *txt == '+' )
+	{
+		retval = HB_AMT_SIGN_INC;
+	}
+	else if( *txt == '-' )
+	{
+		retval = HB_AMT_SIGN_EXP;
+	}
+	return retval;
+}
+
+
+
 static Currency *hb_strfmon_check(gchar *outstr, guint32 kcur)
 {
 Currency *cur = da_cur_get(kcur);
