@@ -495,7 +495,7 @@ static void homebank_pref_get_intlist(
 
 		src = g_key_file_get_integer_list(key_file, group_name, key, &length, NULL);
 
-		DB( g_print(" - length %d (max=%d)\n", (int)length, maxlength) );
+		DB( g_print(" - length %d (max=%d)\n", (int)length, (int)maxlength) );
 		if( length == maxlength )
 		{
 			DB( g_print(" > storing\n") );
@@ -956,9 +956,9 @@ GError *error = NULL;
 				homebank_pref_get_short(keyfile, group, "FiscYearDay", &PREFS->fisc_year_day);
 				homebank_pref_get_short(keyfile, group, "FiscYearMonth", &PREFS->fisc_year_month);
 
-				//5.8 payment
+				//5.8 payment, NUM_PAYMODE_KEY-1 because PAYMODE_OBSOLETEINTXFER
 				PREFS->lst_paymode[0] = PAYMODE_NONE;
-				homebank_pref_get_intlist(keyfile, group, "Payment", &PREFS->lst_paymode[1], NUM_PAYMODE_KEY);
+				homebank_pref_get_intlist(keyfile, group, "Payment", &PREFS->lst_paymode[1], NUM_PAYMODE_KEY-1);
 
 
 			group = "Windows";
@@ -1337,7 +1337,7 @@ GError *error = NULL;
 		g_key_file_set_integer     (keyfile, group, "FiscYearDay" , PREFS->fisc_year_day);
 		g_key_file_set_integer     (keyfile, group, "FiscYearMonth" , PREFS->fisc_year_month);
 
-		//5.8 payment
+		//5.8 payment, NUM_PAYMODE_KEY-1 because PAYMODE_OBSOLETEINTXFER
 		g_key_file_set_integer_list(keyfile, group, "Payment", &PREFS->lst_paymode[1], NUM_PAYMODE_KEY-1);
 
 		// added v3.4
