@@ -79,7 +79,7 @@ extern HbKvData CYA_REPORT_INTVL[];
 
 
 
-static void repstats_action_viewlist(GtkRadioButton *toolbutton, gpointer user_data)
+static void repstats_action_viewlist(GtkWidget *toolbutton, gpointer user_data)
 {
 struct repstats_data *data = user_data;
 gint tmpmode;
@@ -95,12 +95,12 @@ gint tmpmode;
 }
 
 
-static void repstats_action_mode_changed(GtkRadioButton *radiobutton, gpointer user_data)
+static void repstats_action_mode_changed(GtkWidget *toolbutton, gpointer user_data)
 {
 struct repstats_data *data = user_data;
 
 	gtk_toggle_tool_button_set_active(GTK_TOGGLE_TOOL_BUTTON(data->BT_list), TRUE);
-	repstats_action_viewlist(radiobutton, data);
+	repstats_action_viewlist(toolbutton, data);
 	
 	if( data->detail == TRUE )
 	{
@@ -266,12 +266,19 @@ Filter *newflt;
 		DB( g_print(" key:%d, copy filter\n", newflt->key) );
 		da_flt_copy(newflt, data->filter);
 
+		//#2073805
+		//hbtk_combo_box_set_active_id(GTK_COMBO_BOX(data->CY_range), data->filter->range);
+		g_signal_handler_block(data->CY_range, data->handler_id[HID_REPDIST_RANGE]);
 		hbtk_combo_box_set_active_id(GTK_COMBO_BOX(data->CY_range), data->filter->range);
+		g_signal_handler_unblock(data->CY_range, data->handler_id[HID_REPDIST_RANGE]);
+
+		repstats_update_date_widget(data->window, NULL);
+		repstats_update_daterange(data->window, NULL);
+		repstats_compute(data->window, NULL);
+		ui_flt_manage_header_sensitive(data->PO_hubfilter, NULL);
 	}
 	else
 		beta_repstats_filter_cb_reset(widget, user_data);
-
-	ui_flt_manage_header_sensitive(data->PO_hubfilter, NULL);
 }
 
 
